==> ff-global-4.0.7.tgz: package/main/preload-main.ts <==
/**
 * @用途
 * @author 黄敏
 * @创建时间 2022-08-19 16:11
 **/

import {app, BrowserWindow, ipcMain, IpcMainEvent, session} from 'electron'
import CookiesSetDetails = Electron.CookiesSetDetails;

//获取windowBrowser id
ipcMain.on('getWebContentId', (e: IpcMainEvent) => {
  e.returnValue = e.sender.id
})

//请求更新插件
ipcMain.on('updateExtension',()=>{
    ff.gc.send('重新获取扩展列表')
})

//获取cookie
type CookiesGetFilter = Electron.CookiesGetFilter
ipcMain.handle('get-cookie', async (e: any, data: CookiesGetFilter) => {
  const result = await session.defaultSession.cookies.get(data)
  return result
})


ipcMain.handle('set-cookie', async (e: any, data: CookiesSetDetails) => {
  const result = await session.defaultSession.cookies.set(data)
  return result
})


ipcMain.on('$window/close', (event, isExit: boolean) => {
  if (isExit) {
    BrowserWindow.getAllWindows().forEach(w => {
      w.destroy()
    })
    //强制即出程序
    if (process.platform !== 'darwin') {
      app.quit()
      process.exit(0)
    }
  } else {
    let bw = BrowserWindow.fromWebContents(event.sender)
    bw && bw.close()
  }
})

//窗口最大化、取消最大化
ipcMain.on('$window/maximize', event => {
  let br = BrowserWindow.fromWebContents(event.sender)
  if (!br) return

  if (br.isMaximized()) {
    br.unmaximize()
  } else {
    br.maximize()
  }
})

//窗口最小化
ipcMain.on('$window/minimize', event => {
  let bw = BrowserWindow.fromWebContents(event.sender)
  bw && bw.minimize()
})

//窗口隐藏
ipcMain.on('$window/hide', (event: IpcMainEvent) => {
  let bw = BrowserWindow.fromWebContents(event.sender)
  if (bw) bw.hide()
})

==> ff-global-4.0.12.tgz: package/main/preload-main.ts <==
/**
 * @用途
 * @author 黄敏
 * @创建时间 2022-08-19 16:11
 **/

import {app, BrowserWindow, ipcMain, IpcMainEvent, session} from 'electron'
import CookiesSetDetails = Electron.CookiesSetDetails;

//获取windowBrowser id
ipcMain.on('getWebContentId', (e: IpcMainEvent) => {
  e.returnValue = e.sender.id
})

//请求更新插件
ipcMain.on('updateExtension',()=>{
    ff.gc.send('重新获取扩展列表')
})

//获取cookie
type CookiesGetFilter = Electron.CookiesGetFilter
ipcMain.handle('get-cookie', async (e: any, data: CookiesGetFilter) => {
  const result = await session.defaultSession.cookies.get(data)
  return result
})


ipcMain.handle('set-cookie', async (e: any, data: CookiesSetDetails) => {
  const result = await session.defaultSession.cookies.set(data)
  return result
})


ipcMain.on('$window/close', (event, isExit: boolean,isDestroy?:boolean) => {
  if (isExit) {
    BrowserWindow.getAllWindows().forEach(w => {
      w.destroy()
    })
    //强制即出程序
    if (process.platform !== 'darwin') {
      app.quit()
      process.exit(0)
    }
  } else {

    let bw = BrowserWindow.fromWebContents(event.sender)
    if(bw){
      if(isDestroy){
        bw.destroy()
      }else{
        bw.close()
      }
    }

  }
})



//窗口最大化、取消最大化
ipcMain.on('$window/maximize', event => {
  let br = BrowserWindow.fromWebContents(event.sender)
  if (!br) return

  if (br.isMaximized()) {
    br.unmaximize()
  } else {
    br.maximize()
  }
})

//窗口最小化
ipcMain.on('$window/minimize', event => {
  let bw = BrowserWindow.fromWebContents(event.sender)
  bw && bw.minimize()
})

//窗口隐藏
ipcMain.on('$window/hide', (event: IpcMainEvent) => {
  let bw = BrowserWindow.fromWebContents(event.sender)
  if (bw) bw.hide()
})
